# Copyright (c) 2012 Cloudera, Inc. All rights reserved.

from cmf.monitor.jmx_beans import JsonParserJmx

class JsonParser(JsonParserJmx):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what we expect.
    """
    JsonParserJmx.__init__(self, json_dict, 'NAMENODE')

# Collected from bolt CDH4 active, federated NN on 10/18/2012.
SAMPLE = r"""
{
  "beans" : [ {
    "name" : "java.lang:type=MemoryPool,name=PS Eden Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Eden Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 1171521536,
      "init" : 197722112,
      "max" : 1175388160,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 1189478400,
      "init" : 197722112,
      "max" : 1190723584,
      "used" : 1189478400
    },
    "Usage" : {
      "committed" : 1171521536,
      "init" : 197722112,
      "max" : 1175388160,
      "used" : 188560984
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=Memory",
    "modelerType" : "sun.management.MemoryImpl",
    "Verbose" : false,
    "HeapMemoryUsage" : {
      "committed" : 2030174208,
      "init" : 790667136,
      "max" : 3193307136,
      "used" : 852761248
    },
    "NonHeapMemoryUsage" : {
      "committed" : 90177536,
      "init" : 24313856,
      "max" : 136314880,
      "used" : 55879872
    },
    "ObjectPendingFinalizationCount" : 0
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Survivor Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Survivor Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 9371648,
      "init" : 32899072,
      "max" : 9371648,
      "used" : 9332024
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 339148800,
      "init" : 32899072,
      "max" : 339148800,
      "used" : 211850184
    },
    "Usage" : {
      "committed" : 9371648,
      "init" : 32899072,
      "max" : 9371648,
      "used" : 9332024
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS MarkSweep",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 13,
      "duration" : 2904,
      "endTime" : 60310440,
      "id" : 2,
      "memoryUsageAfterGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 7208960,
          "init" : 32899072,
          "max" : 7208960,
          "used" : 0
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 849281024,
          "init" : 527171584,
          "max" : 2394947584,
          "used" : 444802504
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 81068032,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 46700416
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 8716288,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 8555072
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 133038080,
          "init" : 197722112,
          "max" : 1181679616,
          "used" : 0
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 7208960,
          "init" : 32899072,
          "max" : 7208960,
          "used" : 6433248
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 875823104,
          "init" : 527171584,
          "max" : 2394947584,
          "used" : 875303144
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 60948480,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 46700416
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 8716288,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 8555072
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 133038080,
          "init" : 197722112,
          "max" : 1181679616,
          "used" : 0
        }
      } ],
      "startTime" : 60307536
    },
    "CollectionCount" : 2,
    "CollectionTime" : 4423,
    "Name" : "PS MarkSweep",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space", "PS Old Gen", "PS Perm Gen" ]
  }, {
    "name" : "Hadoop:service=NameNode,name=IPCLoggerChannel-172.29.111.197-8485",
    "modelerType" : "IPCLoggerChannel-172.29.111.197-8485",
    "tag.Context" : "dfs",
    "tag.IsOutOfSync" : "false",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "QueuedEditsSize" : 0,
    "LagTimeMillis" : 15,
    "CurrentLagTxns" : 0
  }, {
    "name" : "Hadoop:service=NameNode,name=RpcActivityForPort8020",
    "modelerType" : "RpcActivityForPort8020",
    "tag.port" : "8020",
    "tag.Context" : "rpc",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "ReceivedBytes" : 7022755581,
    "SentBytes" : 35197289672,
    "RpcQueueTimeNumOps" : 27967910,
    "RpcQueueTimeAvgTime" : 0.13217623497997336,
    "RpcProcessingTimeNumOps" : 27967910,
    "RpcProcessingTimeAvgTime" : 3.056074766355141,
    "RpcAuthenticationFailures" : 0,
    "RpcAuthenticationSuccesses" : 0,
    "RpcAuthorizationFailures" : 0,
    "RpcAuthorizationSuccesses" : 1283224,
    "NumOpenConnections" : 126,
    "CallQueueLength" : 0
  }, {
    "name" : "Hadoop:service=NameNode,name=NameNodeActivity",
    "modelerType" : "NameNodeActivity",
    "tag.ProcessName" : "NameNode",
    "tag.SessionId" : null,
    "tag.Context" : "dfs",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "CreateFileOps" : 412310,
    "FilesCreated" : 573435,
    "FilesAppended" : 0,
    "GetBlockLocations" : 11230246,
    "FilesRenamed" : 386674,
    "GetListingOps" : 558596,
    "DeleteFileOps" : 333932,
    "FilesDeleted" : 569968,
    "FileInfoOps" : 4465626,
    "AddBlockOps" : 499719,
    "GetAdditionalDatanodeOps" : 6,
    "CreateSymlinkOps" : 0,
    "GetLinkTargetOps" : 0,
    "FilesInGetListingOps" : 27176259,
    "TransactionsNumOps" : 3471547,
    "TransactionsAvgTime" : 0.0,
    "SyncsNumOps" : 1089632,
    "SyncsAvgTime" : 39.0,
    "TransactionsBatchedInSync" : 1244222,
    "BlockReportNumOps" : 815,
    "BlockReportAvgTime" : 30.0,
    "SafeModeTime" : 397949,
    "FsImageLoadTime" : 6956
  }, {
    "name" : "java.lang:type=Compilation",
    "modelerType" : "sun.management.CompilationImpl",
    "Name" : "HotSpot 64-Bit Tiered Compilers",
    "CompilationTimeMonitoringSupported" : true,
    "TotalCompilationTime" : 34969
  }, {
    "name" : "Hadoop:service=NameNode,name=IPCLoggerChannel-172.29.111.198-8485",
    "modelerType" : "IPCLoggerChannel-172.29.111.198-8485",
    "tag.Context" : "dfs",
    "tag.IsOutOfSync" : "false",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "QueuedEditsSize" : 0,
    "LagTimeMillis" : 15,
    "CurrentLagTxns" : 0
  }, {
    "name" : "java.lang:type=OperatingSystem",
    "modelerType" : "com.sun.management.UnixOperatingSystem",
    "MaxFileDescriptorCount" : 32768,
    "OpenFileDescriptorCount" : 320,
    "CommittedVirtualMemorySize" : 4312408064,
    "FreePhysicalMemorySize" : 28167983104,
    "FreeSwapSpaceSize" : 25370288128,
    "ProcessCpuTime" : 12056240000000,
    "TotalPhysicalMemorySize" : 50602696704,
    "TotalSwapSpaceSize" : 25370288128,
    "Name" : "Linux",
    "Version" : "2.6.32-279.el6.x86_64",
    "AvailableProcessors" : 16,
    "Arch" : "amd64",
    "SystemLoadAverage" : 0.05
  }, {
    "name" : "Hadoop:service=NameNode,name=UgiMetrics",
    "modelerType" : "UgiMetrics",
    "tag.Context" : "ugi",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "LoginSuccessNumOps" : 0,
    "LoginSuccessAvgTime" : 0.0,
    "LoginFailureNumOps" : 0,
    "LoginFailureAvgTime" : 0.0
  }, {
    "name" : "java.lang:type=MemoryManager,name=CodeCacheManager",
    "modelerType" : "sun.management.MemoryManagerImpl",
    "Name" : "CodeCacheManager",
    "Valid" : true,
    "MemoryPoolNames" : [ "Code Cache" ]
  }, {
    "name" : "Hadoop:service=NameNode,name=MetricsSystem,sub=Control",
    "modelerType" : "org.apache.hadoop.metrics2.impl.MetricsSystemImpl"
  }, {
    "name" : "Hadoop:service=NameNode,name=RpcDetailedActivityForPort8020",
    "modelerType" : "RpcDetailedActivityForPort8020",
    "tag.port" : "8020",
    "tag.Context" : "rpcdetailed",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "SendHeartbeatNumOps" : 5260865,
    "SendHeartbeatAvgTime" : 2.9771341463414602,
    "VersionRequestNumOps" : 89,
    "VersionRequestAvgTime" : 0.0,
    "RegisterDatanodeNumOps" : 89,
    "RegisterDatanodeAvgTime" : 1.0,
    "BlockReportNumOps" : 816,
    "BlockReportAvgTime" : 31.0,
    "SetSafeModeNumOps" : 43,
    "SetSafeModeAvgTime" : 0.0,
    "GetServiceStatusNumOps" : 1,
    "GetServiceStatusAvgTime" : 11.0,
    "MonitorHealthNumOps" : 1,
    "MonitorHealthAvgTime" : 0.0,
    "TransitionToActiveNumOps" : 1,
    "TransitionToActiveAvgTime" : 2074.0,
    "GetListingNumOps" : 558623,
    "GetListingAvgTime" : 1.0,
    "GetFileInfoNumOps" : 4465602,
    "GetFileInfoAvgTime" : 0.0,
    "ReportBadBlocksNumOps" : 11,
    "ReportBadBlocksAvgTime" : 0.7272727272727274,
    "GetBlockLocationsNumOps" : 11230243,
    "GetBlockLocationsAvgTime" : 1.2173913043478262,
    "GetServerDefaultsNumOps" : 535958,
    "GetServerDefaultsAvgTime" : 0.0,
    "MkdirsNumOps" : 167052,
    "MkdirsAvgTime" : 21.875,
    "CreateNumOps" : 412310,
    "CreateAvgTime" : 51.0,
    "AddBlockNumOps" : 499719,
    "AddBlockAvgTime" : 21.0,
    "BlockReceivedAndDeletedNumOps" : 2998807,
    "BlockReceivedAndDeletedAvgTime" : 0.0,
    "FsyncNumOps" : 105651,
    "FsyncAvgTime" : 21.0,
    "RenameNumOps" : 386672,
    "RenameAvgTime" : 20.46428571428571,
    "SetPermissionNumOps" : 8390,
    "SetPermissionAvgTime" : 15.999999999999998,
    "DeleteNumOps" : 334277,
    "DeleteAvgTime" : 20.0,
    "CompleteNumOps" : 412953,
    "CompleteAvgTime" : 24.0,
    "RecoverLeaseNumOps" : 590,
    "RecoverLeaseAvgTime" : 14.5,
    "RollEditLogNumOps" : 1484,
    "RollEditLogAvgTime" : 307.0,
    "RenewLeaseNumOps" : 583577,
    "RenewLeaseAvgTime" : 0.014705882352941176,
    "GetAdditionalDatanodeNumOps" : 5,
    "GetAdditionalDatanodeAvgTime" : 0.0,
    "UpdateBlockForPipelineNumOps" : 5,
    "UpdateBlockForPipelineAvgTime" : 25.0,
    "UpdatePipelineNumOps" : 5,
    "UpdatePipelineAvgTime" : 19.0,
    "SetReplicationNumOps" : 4066,
    "SetReplicationAvgTime" : 17.0,
    "Rename2NumOps" : 3,
    "Rename2AvgTime" : 18.5,
    "SetOwnerNumOps" : 1,
    "SetOwnerAvgTime" : 13.0,
    "CommitBlockSynchronizationNumOps" : 1,
    "CommitBlockSynchronizationAvgTime" : 20.0
  }, {
    "name" : "Hadoop:service=NameNode,name=JvmMetrics",
    "modelerType" : "JvmMetrics",
    "tag.Context" : "jvm",
    "tag.ProcessName" : "NameNode",
    "tag.SessionId" : null,
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "MemNonHeapUsedM" : 53.2912,
    "MemNonHeapCommittedM" : 86.0,
    "MemHeapUsedM" : 813.4682,
    "MemHeapCommittedM" : 1936.125,
    "GcCount" : 2915,
    "GcTimeMillis" : 174426,
    "ThreadsNew" : 0,
    "ThreadsRunnable" : 7,
    "ThreadsBlocked" : 0,
    "ThreadsWaiting" : 98,
    "ThreadsTimedWaiting" : 14,
    "ThreadsTerminated" : 0,
    "LogFatal" : 0,
    "LogError" : 146,
    "LogWarn" : 413,
    "LogInfo" : 3303986
  }, {
    "name" : "Hadoop:service=NameNode,name=FSNamesystemState",
    "modelerType" : "org.apache.hadoop.hdfs.server.namenode.FSNamesystem",
    "CapacityTotal" : 498746741862400,
    "CapacityUsed" : 361522355743464,
    "CapacityRemaining" : 135824711236402,
    "TotalLoad" : 763,
    "BlocksTotal" : 2269216,
    "FilesTotal" : 1479585,
    "PendingReplicationBlocks" : 1,
    "UnderReplicatedBlocks" : 6593,
    "ScheduledReplicationBlocks" : 0,
    "FSState" : "Operational",
    "NumLiveDataNodes" : 88,
    "NumDeadDataNodes" : 0
  }, {
    "name" : "java.lang:type=MemoryPool,name=Code Cache",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Code Cache",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : null,
    "MemoryManagerNames" : [ "CodeCacheManager" ],
    "PeakUsage" : {
      "committed" : 9109504,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 8892416
    },
    "Usage" : {
      "committed" : 9109504,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 8881856
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdSupported" : false,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=Runtime",
    "modelerType" : "sun.management.RuntimeImpl",
    "Name" : "25144@c1113.hal.cloudera.com",
    "ClassPath" : "/var/run/cloudera-scm-agent/process/50505-hdfs-NAMENODE:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/jsr305-1.3.9.jar:/usr/lib/hadoop/lib/commons-net-3.1.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.8.8.jar:/usr/lib/hadoop/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/mockito-all-1.8.5.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/log4j-1.2.17.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jsch-0.1.42.jar:/usr/lib/hadoop/lib/jackson-xc-1.8.8.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/jline-0.9.94.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/hue-plugins-2.1.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/jaxb-api-2.2.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/stax-api-1.0.1.jar:/usr/lib/hadoop/lib/guava-11.0.2.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/.//hadoop-annotations.jar:/usr/lib/hadoop/.//hadoop-auth.jar:/usr/lib/hadoop/.//hadoop-annotations-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common.jar:/usr/lib/hadoop/.//hadoop-auth-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/share/cmf/lib/plugins/event-publish-4.1.0-SNAPSHOT-shaded.jar:/usr/lib/hadoop-hdfs/./:/usr/lib/hadoop-hdfs/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-hdfs/lib/jsr305-1.3.9.jar:/usr/lib/hadoop-hdfs/lib/jersey-server-1.8.jar:/usr/lib/hadoop-hdfs/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop-hdfs/lib/jsp-api-2.1.jar:/usr/lib/hadoop-hdfs/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop-hdfs/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop-hdfs/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/lib/log4j-1.2.17.jar:/usr/lib/hadoop-hdfs/lib/commons-el-1.0.jar:/usr/lib/hadoop-hdfs/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/servlet-api-2.5.jar:/usr/lib/hadoop-hdfs/lib/commons-io-2.1.jar:/usr/lib/hadoop-hdfs/lib/jline-0.9.94.jar:/usr/lib/hadoop-hdfs/lib/asm-3.2.jar:/usr/lib/hadoop-hdfs/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-codec-1.4.jar:/usr/lib/hadoop-hdfs/lib/commons-lang-2.5.jar:/usr/lib/hadoop-hdfs/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/xmlenc-0.52.jar:/usr/lib/hadoop-hdfs/lib/guava-11.0.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-core-1.8.jar:/usr/lib/hadoop-hdfs/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/commons-cli-1.2.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs.jar:/usr/lib/hadoop-yarn/lib/paranamer-2.3.jar:/usr/lib/hadoop-yarn/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-yarn/lib/jersey-server-1.8.jar:/usr/lib/hadoop-yarn/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-yarn/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-yarn/lib/aopalliance-1.0.jar:/usr/lib/hadoop-yarn/lib/log4j-1.2.17.jar:/usr/lib/hadoop-yarn/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-yarn/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/guice-3.0.jar:/usr/lib/hadoop-yarn/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-yarn/lib/commons-io-2.1.jar:/usr/lib/hadoop-yarn/lib/asm-3.2.jar:/usr/lib/hadoop-yarn/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/javax.inject-1.jar:/usr/lib/hadoop-yarn/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-yarn/lib/jersey-core-1.8.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop-mapreduce/lib/paranamer-2.3.jar:/usr/lib/hadoop-mapreduce/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-mapreduce/lib/jersey-server-1.8.jar:/usr/lib/hadoop-mapreduce/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-mapreduce/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-mapreduce/lib/aopalliance-1.0.jar:/usr/lib/hadoop-mapreduce/lib/log4j-1.2.17.jar:/usr/lib/hadoop-mapreduce/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-mapreduce/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/guice-3.0.jar:/usr/lib/hadoop-mapreduce/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-mapreduce/lib/commons-io-2.1.jar:/usr/lib/hadoop-mapreduce/lib/asm-3.2.jar:/usr/lib/hadoop-mapreduce/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/javax.inject-1.jar:/usr/lib/hadoop-mapreduce/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-mapreduce/lib/jersey-core-1.8.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen.jar",
    "StartTime" : 1350412165736,
    "BootClassPath" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes",
    "LibraryPath" : "/usr/lib/hadoop/lib/native",
    "VmName" : "Java HotSpot(TM) 64-Bit Server VM",
    "VmVendor" : "Sun Microsystems Inc.",
    "VmVersion" : "20.6-b01",
    "BootClassPathSupported" : true,
    "InputArguments" : [ "-Dproc_namenode", "-Xmx1000m", "-Dhdfs.audit.logger=INFO,RFAAUDIT", "-Dsecurity.audit.logger=INFO,RFAS", "-Djava.net.preferIPv4Stack=true", "-Dhadoop.log.dir=/data/1/hadoop-hdfs", "-Dhadoop.log.file=hadoop-cmf-hdfs1-NAMENODE-c1113.hal.cloudera.com.log.out", "-Dhadoop.home.dir=/usr/lib/hadoop", "-Dhadoop.id.str=hdfs", "-Dhadoop.root.logger=INFO,RFA", "-Djava.library.path=/usr/lib/hadoop/lib/native", "-Dhadoop.policy.file=hadoop-policy.xml", "-Djava.net.preferIPv4Stack=true", "-Xmx3592384734", "-Dhadoop.security.logger=INFO,RFAS" ],
    "ManagementSpecVersion" : "1.2",
    "SpecName" : "Java Virtual Machine Specification",
    "SpecVendor" : "Sun Microsystems Inc.",
    "SpecVersion" : "1.0",
    "SystemProperties" : [ {
      "key" : "security.audit.logger",
      "value" : "INFO,RFAS"
    }, {
      "key" : "java.ext.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/ext:/usr/java/packages/lib/ext"
    }, {
      "key" : "hadoop.home.dir",
      "value" : "/usr/lib/hadoop"
    }, {
      "key" : "java.vm.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.timezone",
      "value" : "US/Pacific"
    }, {
      "key" : "hadoop.id.str",
      "value" : "hdfs"
    }, {
      "key" : "java.vm.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.name",
      "value" : "hdfs"
    }, {
      "key" : "java.vm.specification.name",
      "value" : "Java Virtual Machine Specification"
    }, {
      "key" : "user.dir",
      "value" : "/var/run/cloudera-scm-agent/process/50505-hdfs-NAMENODE"
    }, {
      "key" : "user.country",
      "value" : "US"
    }, {
      "key" : "user.language",
      "value" : "en"
    }, {
      "key" : "java.specification.version",
      "value" : "1.6"
    }, {
      "key" : "hadoop.log.file",
      "value" : "hadoop-cmf-hdfs1-NAMENODE-c1113.hal.cloudera.com.log.out"
    }, {
      "key" : "hadoop.policy.file",
      "value" : "hadoop-policy.xml"
    }, {
      "key" : "sun.cpu.endian",
      "value" : "little"
    }, {
      "key" : "java.home",
      "value" : "/usr/java/jdk1.6.0_31/jre"
    }, {
      "key" : "java.net.preferIPv4Stack",
      "value" : "true"
    }, {
      "key" : "sun.jnu.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "file.separator",
      "value" : "/"
    }, {
      "key" : "java.vendor.url",
      "value" : "http://java.sun.com/"
    }, {
      "key" : "java.awt.graphicsenv",
      "value" : "sun.awt.X11GraphicsEnvironment"
    }, {
      "key" : "hadoop.log.dir",
      "value" : "/data/1/hadoop-hdfs"
    }, {
      "key" : "os.arch",
      "value" : "amd64"
    }, {
      "key" : "java.io.tmpdir",
      "value" : "/tmp"
    }, {
      "key" : "java.runtime.name",
      "value" : "Java(TM) SE Runtime Environment"
    }, {
      "key" : "java.awt.printerjob",
      "value" : "sun.print.PSPrinterJob"
    }, {
      "key" : "file.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "java.version",
      "value" : "1.6.0_31"
    }, {
      "key" : "java.vendor.url.bug",
      "value" : "http://java.sun.com/cgi-bin/bugreport.cgi"
    }, {
      "key" : "java.vm.specification.version",
      "value" : "1.0"
    }, {
      "key" : "file.encoding.pkg",
      "value" : "sun.io"
    }, {
      "key" : "sun.java.command",
      "value" : "org.apache.hadoop.hdfs.server.namenode.NameNode"
    }, {
      "key" : "sun.java.launcher",
      "value" : "SUN_STANDARD"
    }, {
      "key" : "path.separator",
      "value" : ":"
    }, {
      "key" : "java.runtime.version",
      "value" : "1.6.0_31-b04"
    }, {
      "key" : "java.class.path",
      "value" : "/var/run/cloudera-scm-agent/process/50505-hdfs-NAMENODE:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/jsr305-1.3.9.jar:/usr/lib/hadoop/lib/commons-net-3.1.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.8.8.jar:/usr/lib/hadoop/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/mockito-all-1.8.5.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/log4j-1.2.17.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jsch-0.1.42.jar:/usr/lib/hadoop/lib/jackson-xc-1.8.8.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/jline-0.9.94.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/hue-plugins-2.1.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/jaxb-api-2.2.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/stax-api-1.0.1.jar:/usr/lib/hadoop/lib/guava-11.0.2.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/.//hadoop-annotations.jar:/usr/lib/hadoop/.//hadoop-auth.jar:/usr/lib/hadoop/.//hadoop-annotations-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common.jar:/usr/lib/hadoop/.//hadoop-auth-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/share/cmf/lib/plugins/event-publish-4.1.0-SNAPSHOT-shaded.jar:/usr/lib/hadoop-hdfs/./:/usr/lib/hadoop-hdfs/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-hdfs/lib/jsr305-1.3.9.jar:/usr/lib/hadoop-hdfs/lib/jersey-server-1.8.jar:/usr/lib/hadoop-hdfs/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop-hdfs/lib/jsp-api-2.1.jar:/usr/lib/hadoop-hdfs/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop-hdfs/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop-hdfs/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/lib/log4j-1.2.17.jar:/usr/lib/hadoop-hdfs/lib/commons-el-1.0.jar:/usr/lib/hadoop-hdfs/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/servlet-api-2.5.jar:/usr/lib/hadoop-hdfs/lib/commons-io-2.1.jar:/usr/lib/hadoop-hdfs/lib/jline-0.9.94.jar:/usr/lib/hadoop-hdfs/lib/asm-3.2.jar:/usr/lib/hadoop-hdfs/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-codec-1.4.jar:/usr/lib/hadoop-hdfs/lib/commons-lang-2.5.jar:/usr/lib/hadoop-hdfs/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/xmlenc-0.52.jar:/usr/lib/hadoop-hdfs/lib/guava-11.0.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-core-1.8.jar:/usr/lib/hadoop-hdfs/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/commons-cli-1.2.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs.jar:/usr/lib/hadoop-yarn/lib/paranamer-2.3.jar:/usr/lib/hadoop-yarn/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-yarn/lib/jersey-server-1.8.jar:/usr/lib/hadoop-yarn/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-yarn/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-yarn/lib/aopalliance-1.0.jar:/usr/lib/hadoop-yarn/lib/log4j-1.2.17.jar:/usr/lib/hadoop-yarn/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-yarn/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/guice-3.0.jar:/usr/lib/hadoop-yarn/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-yarn/lib/commons-io-2.1.jar:/usr/lib/hadoop-yarn/lib/asm-3.2.jar:/usr/lib/hadoop-yarn/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/javax.inject-1.jar:/usr/lib/hadoop-yarn/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-yarn/lib/jersey-core-1.8.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop-mapreduce/lib/paranamer-2.3.jar:/usr/lib/hadoop-mapreduce/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-mapreduce/lib/jersey-server-1.8.jar:/usr/lib/hadoop-mapreduce/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-mapreduce/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-mapreduce/lib/aopalliance-1.0.jar:/usr/lib/hadoop-mapreduce/lib/log4j-1.2.17.jar:/usr/lib/hadoop-mapreduce/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-mapreduce/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/guice-3.0.jar:/usr/lib/hadoop-mapreduce/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-mapreduce/lib/commons-io-2.1.jar:/usr/lib/hadoop-mapreduce/lib/asm-3.2.jar:/usr/lib/hadoop-mapreduce/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/javax.inject-1.jar:/usr/lib/hadoop-mapreduce/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-mapreduce/lib/jersey-core-1.8.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen.jar"
    }, {
      "key" : "os.name",
      "value" : "Linux"
    }, {
      "key" : "hadoop.security.logger",
      "value" : "INFO,RFAS"
    }, {
      "key" : "line.separator",
      "value" : "\n"
    }, {
      "key" : "proc_namenode",
      "value" : ""
    }, {
      "key" : "os.version",
      "value" : "2.6.32-279.el6.x86_64"
    }, {
      "key" : "sun.arch.data.model",
      "value" : "64"
    }, {
      "key" : "java.class.version",
      "value" : "50.0"
    }, {
      "key" : "sun.io.unicode.encoding",
      "value" : "UnicodeLittle"
    }, {
      "key" : "java.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.boot.class.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes"
    }, {
      "key" : "java.vm.info",
      "value" : "mixed mode"
    }, {
      "key" : "java.specification.name",
      "value" : "Java Platform API Specification"
    }, {
      "key" : "java.vm.name",
      "value" : "Java HotSpot(TM) 64-Bit Server VM"
    }, {
      "key" : "java.vm.version",
      "value" : "20.6-b01"
    }, {
      "key" : "sun.boot.library.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/amd64"
    }, {
      "key" : "hadoop.root.logger",
      "value" : "INFO,RFA"
    }, {
      "key" : "java.endorsed.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/endorsed"
    }, {
      "key" : "sun.os.patch.level",
      "value" : "unknown"
    }, {
      "key" : "sun.cpu.isalist",
      "value" : ""
    }, {
      "key" : "hdfs.audit.logger",
      "value" : "INFO,RFAAUDIT"
    }, {
      "key" : "user.home",
      "value" : "/usr/lib/hadoop-0.20"
    }, {
      "key" : "java.library.path",
      "value" : "/usr/lib/hadoop/lib/native"
    }, {
      "key" : "java.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.management.compiler",
      "value" : "HotSpot 64-Bit Tiered Compilers"
    } ],
    "Uptime" : 179449007
  }, {
    "name" : "java.lang:type=ClassLoading",
    "modelerType" : "sun.management.ClassLoadingImpl",
    "LoadedClassCount" : 5003,
    "UnloadedClassCount" : 2,
    "TotalLoadedClassCount" : 5005,
    "Verbose" : false
  }, {
    "name" : "Hadoop:service=NameNode,name=IPCLoggerChannel-172.29.111.243-8485",
    "modelerType" : "IPCLoggerChannel-172.29.111.243-8485",
    "tag.Context" : "dfs",
    "tag.IsOutOfSync" : "false",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "QueuedEditsSize" : 0,
    "LagTimeMillis" : 15,
    "CurrentLagTxns" : 0
  }, {
    "name" : "java.lang:type=Threading",
    "modelerType" : "sun.management.ThreadImpl",
    "ThreadAllocatedMemoryEnabled" : true,
    "ThreadAllocatedMemorySupported" : true,
    "DaemonThreadCount" : 114,
    "PeakThreadCount" : 227,
    "CurrentThreadCpuTimeSupported" : true,
    "ObjectMonitorUsageSupported" : true,
    "SynchronizerUsageSupported" : true,
    "ThreadContentionMonitoringEnabled" : false,
    "ThreadContentionMonitoringSupported" : true,
    "ThreadCpuTimeEnabled" : true,
    "AllThreadIds" : [ 15777, 15774, 15776, 15775, 15109, 162, 161, 160, 159, 154, 153, 152, 129, 128, 125, 124, 123, 122, 121, 120, 119, 118, 117, 116, 115, 114, 113, 112, 111, 110, 109, 108, 107, 106, 105, 104, 103, 102, 101, 100, 99, 98, 97, 96, 95, 94, 93, 92, 91, 90, 89, 88, 87, 86, 85, 84, 83, 82, 81, 80, 79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47, 46, 45, 44, 43, 42, 41, 40, 39, 38, 37, 23, 25, 36, 35, 34, 12, 13, 31, 30, 24, 11, 9, 4, 3, 2, 1 ],
    "CurrentThreadCpuTime" : 6890000000,
    "CurrentThreadUserTime" : 4780000000,
    "ThreadCount" : 119,
    "TotalStartedThreadCount" : 15771,
    "ThreadCpuTimeSupported" : true
  }, {
    "name" : "Hadoop:service=NameNode,name=FSNamesystem",
    "modelerType" : "FSNamesystem",
    "tag.Context" : "dfs",
    "tag.HAState" : "active",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "MissingBlocks" : 6593,
    "ExpiredHeartbeats" : 0,
    "TransactionsSinceLastCheckpoint" : 23631,
    "TransactionsSinceLastLogRoll" : 1,
    "LastWrittenTransactionId" : 517133448,
    "LastCheckpointTime" : 1350588011670,
    "CapacityTotalGB" : 464494.0,
    "CapacityUsedGB" : 336694.0,
    "CapacityRemainingGB" : 126497.0,
    "TotalLoad" : 763,
    "BlocksTotal" : 2269216,
    "FilesTotal" : 1479585,
    "PendingReplicationBlocks" : 1,
    "UnderReplicatedBlocks" : 6593,
    "CorruptBlocks" : 7,
    "ScheduledReplicationBlocks" : 0,
    "PendingDeletionBlocks" : 0,
    "ExcessBlocks" : 2,
    "PostponedMisreplicatedBlocks" : 0,
    "PendingDataNodeMessageCount" : 0,
    "MillisSinceLastLoadedEdits" : 0,
    "BlockCapacity" : 8388608,
    "TotalFiles" : 1479585
  }, {
    "name" : "java.util.logging:type=Logging",
    "modelerType" : "java.util.logging.Logging",
    "LoggerNames" : [ "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioWorker", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.CompleteChannelFuture", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioProviderMetadata", "com.google.common.util.concurrent.ExecutionList", "javax.management", "com.google.common.util.concurrent.UncaughtExceptionHandlers$Exiter", "sun.net.www.protocol.http.HttpURLConnection", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.DefaultChannelPipeline", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioClientSocketChannel", "sun.awt.AppContext", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioClientSocketPipelineSink", "global", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.SimpleChannelUpstreamHandler", "javax.management.mbeanserver", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.DefaultChannelFuture", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.DefaultNioSocketChannelConfig", "com.cloudera.cmf.event.shaded.org.jboss.netty.util.ThreadRenamingRunnable", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.SelectorUtil", "" ]
  }, {
    "name" : "Hadoop:service=NameNode,name=MetricsSystem,sub=Stats",
    "modelerType" : "MetricsSystem,sub=Stats",
    "tag.Context" : "metricssystem",
    "tag.Hostname" : "c1113.hal.cloudera.com",
    "NumActiveSources" : 9,
    "NumAllSources" : 9,
    "NumActiveSinks" : 0,
    "NumAllSinks" : 0,
    "SnapshotNumOps" : 0,
    "SnapshotAvgTime" : 0.0,
    "PublishNumOps" : 0,
    "PublishAvgTime" : 0.0,
    "DroppedPubAll" : 0
  }, {
    "name" : "Hadoop:service=NameNode,name=NameNodeInfo",
    "modelerType" : "org.apache.hadoop.hdfs.server.namenode.FSNamesystem",
    "Threads" : 119,
    "Total" : 498746741862400,
    "ClusterId" : "cluster24",
    "BlockPoolId" : "BP-1507505631-172.29.111.243-1337120439433",
    "Used" : 361522355743464,
    "PercentUsed" : 72.48616,
    "PercentRemaining" : 27.233204,
    "Version" : "2.0.0-cdh4.1.1-SNAPSHOT, r4153a4877e2cea2e38010dde7cf51c90076632bc",
    "Free" : 135824711236402,
    "Safemode" : "",
    "UpgradeFinalized" : true,
    "NonDfsUsedSpace" : 1399674882534,
    "BlockPoolUsedSpace" : 361522342169387,
    "PercentBlockPoolUsed" : 72.48616,
    "TotalBlocks" : 2269216,
    "TotalFiles" : 1479585,
    "NumberOfMissingBlocks" : 6593,
    "LiveNodes" : "{\"c0816.hal.cloudera.com\":{\"numBlocks\":50922,\"usedSpace\":4280795717632,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":1551306752,\"adminState\":\"In Service\"},\"c1015.hal.cloudera.com\":{\"numBlocks\":46991,\"usedSpace\":4189879696838,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1020.hal.cloudera.com\":{\"numBlocks\":46222,\"usedSpace\":3904677994496,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":21428879360,\"adminState\":\"In Service\"},\"c1104.hal.cloudera.com\":{\"numBlocks\":52881,\"usedSpace\":4416852295840,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":20781985792,\"adminState\":\"In Service\"},\"c1032.hal.cloudera.com\":{\"numBlocks\":43272,\"usedSpace\":3658406200107,\"lastContact\":0,\"capacity\":4698971291648,\"nonDfsUsedSpace\":23722532864,\"adminState\":\"In Service\"},\"c1029.hal.cloudera.com\":{\"numBlocks\":48457,\"usedSpace\":4254786178876,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1006.hal.cloudera.com\":{\"numBlocks\":45650,\"usedSpace\":3879602968174,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22158950400,\"adminState\":\"In Service\"},\"c0822.hal.cloudera.com\":{\"numBlocks\":51806,\"usedSpace\":4520641526301,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22553718784,\"adminState\":\"In Service\"},\"c0833.hal.cloudera.com\":{\"numBlocks\":52093,\"usedSpace\":4409276886746,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0832.hal.cloudera.com\":{\"numBlocks\":49017,\"usedSpace\":4240172951719,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1107.hal.cloudera.com\":{\"numBlocks\":53437,\"usedSpace\":4546112768450,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":23203268158,\"adminState\":\"In Service\"},\"c1030.hal.cloudera.com\":{\"numBlocks\":47033,\"usedSpace\":4077055917202,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1033.hal.cloudera.com\":{\"numBlocks\":45647,\"usedSpace\":3900470798735,\"lastContact\":1,\"capacity\":5672740315136,\"nonDfsUsedSpace\":42351910912,\"adminState\":\"In Service\"},\"c0905.hal.cloudera.com\":{\"numBlocks\":47933,\"usedSpace\":4117859197452,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0916.hal.cloudera.com\":{\"numBlocks\":47897,\"usedSpace\":4191539865452,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1018.hal.cloudera.com\":{\"numBlocks\":47577,\"usedSpace\":4163430346752,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0823.hal.cloudera.com\":{\"numBlocks\":51447,\"usedSpace\":4339416663736,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22642724864,\"adminState\":\"In Service\"},\"c0909.hal.cloudera.com\":{\"numBlocks\":48040,\"usedSpace\":4192439233636,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0932.hal.cloudera.com\":{\"numBlocks\":47510,\"usedSpace\":4055045687082,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22072569856,\"adminState\":\"In Service\"},\"c1026.hal.cloudera.com\":{\"numBlocks\":45719,\"usedSpace\":3865904474418,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0815.hal.cloudera.com\":{\"numBlocks\":50878,\"usedSpace\":4369220386384,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":21357764608,\"adminState\":\"In Service\"},\"c1007.hal.cloudera.com\":{\"numBlocks\":47627,\"usedSpace\":4135116665828,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0817.hal.cloudera.com\":{\"numBlocks\":44318,\"usedSpace\":3616879172550,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":20820766720,\"adminState\":\"In Service\"},\"c1019.hal.cloudera.com\":{\"numBlocks\":44874,\"usedSpace\":3910754422784,\"lastContact\":1,\"capacity\":5672740315136,\"nonDfsUsedSpace\":39644717056,\"adminState\":\"In Service\"},\"c1108.hal.cloudera.com\":{\"numBlocks\":31350,\"usedSpace\":2956148428800,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1008.hal.cloudera.com\":{\"numBlocks\":44258,\"usedSpace\":3724439330816,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":20862156800,\"adminState\":\"In Service\"},\"c0915.hal.cloudera.com\":{\"numBlocks\":47025,\"usedSpace\":4069071112095,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":273969698913,\"adminState\":\"In Service\"},\"c1011.hal.cloudera.com\":{\"numBlocks\":45590,\"usedSpace\":3940741415971,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0919.hal.cloudera.com\":{\"numBlocks\":47395,\"usedSpace\":4093813627290,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0925.hal.cloudera.com\":{\"numBlocks\":48326,\"usedSpace\":4179705966692,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0912.hal.cloudera.com\":{\"numBlocks\":48048,\"usedSpace\":4168595122934,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1109.hal.cloudera.com\":{\"numBlocks\":53848,\"usedSpace\":4575350512903,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0933.hal.cloudera.com\":{\"numBlocks\":29896,\"usedSpace\":2810926543772,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0924.hal.cloudera.com\":{\"numBlocks\":48174,\"usedSpace\":4241172197376,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0923.hal.cloudera.com\":{\"numBlocks\":48480,\"usedSpace\":4247263002624,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0920.hal.cloudera.com\":{\"numBlocks\":48341,\"usedSpace\":4302701053718,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1110.hal.cloudera.com\":{\"numBlocks\":47481,\"usedSpace\":4084553347041,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":24003272113,\"adminState\":\"In Service\"},\"c0825.hal.cloudera.com\":{\"numBlocks\":27291,\"usedSpace\":2572801881745,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":304134760815,\"adminState\":\"In Service\"},\"c1031.hal.cloudera.com\":{\"numBlocks\":46075,\"usedSpace\":4003583815256,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":63962673152,\"adminState\":\"In Service\"},\"c1117.hal.cloudera.com\":{\"numBlocks\":53592,\"usedSpace\":4577090514944,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1016.hal.cloudera.com\":{\"numBlocks\":45061,\"usedSpace\":3915544421630,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0821.hal.cloudera.com\":{\"numBlocks\":49915,\"usedSpace\":4227997789776,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":23567183872,\"adminState\":\"In Service\"},\"c0911.hal.cloudera.com\":{\"numBlocks\":48507,\"usedSpace\":4239052615680,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":21618556928,\"adminState\":\"In Service\"},\"c0910.hal.cloudera.com\":{\"numBlocks\":49005,\"usedSpace\":4245116211200,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0927.hal.cloudera.com\":{\"numBlocks\":48599,\"usedSpace\":4318644375237,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1106.hal.cloudera.com\":{\"numBlocks\":51797,\"usedSpace\":4450609458389,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0826.hal.cloudera.com\":{\"numBlocks\":51554,\"usedSpace\":4550992490496,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0914.hal.cloudera.com\":{\"numBlocks\":42414,\"usedSpace\":3754306975986,\"lastContact\":2,\"capacity\":5672741957632,\"nonDfsUsedSpace\":41770917888,\"adminState\":\"In Service\"},\"c0917.hal.cloudera.com\":{\"numBlocks\":47400,\"usedSpace\":4100570889716,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0904.hal.cloudera.com\":{\"numBlocks\":48023,\"usedSpace\":4155240034187,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0831.hal.cloudera.com\":{\"numBlocks\":50931,\"usedSpace\":4299466690560,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1025.hal.cloudera.com\":{\"numBlocks\":46440,\"usedSpace\":4023396103145,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0907.hal.cloudera.com\":{\"numBlocks\":48592,\"usedSpace\":4207145774482,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0828.hal.cloudera.com\":{\"numBlocks\":46579,\"usedSpace\":3933309436043,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0918.hal.cloudera.com\":{\"numBlocks\":47659,\"usedSpace\":4147774039013,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":20947619840,\"adminState\":\"In Service\"},\"c1028.hal.cloudera.com\":{\"numBlocks\":45630,\"usedSpace\":3990750594711,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1014.hal.cloudera.com\":{\"numBlocks\":39680,\"usedSpace\":3461826486301,\"lastContact\":0,\"capacity\":5672740315136,\"nonDfsUsedSpace\":39634460672,\"adminState\":\"In Service\"},\"c1116.hal.cloudera.com\":{\"numBlocks\":52479,\"usedSpace\":4505495458641,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1111.hal.cloudera.com\":{\"numBlocks\":52877,\"usedSpace\":4558369088412,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0827.hal.cloudera.com\":{\"numBlocks\":51214,\"usedSpace\":4480241375565,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1023.hal.cloudera.com\":{\"numBlocks\":46581,\"usedSpace\":4041423196160,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0913.hal.cloudera.com\":{\"numBlocks\":56561,\"usedSpace\":5425816064000,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":107757813760,\"adminState\":\"In Service\"},\"c0908.hal.cloudera.com\":{\"numBlocks\":46580,\"usedSpace\":4005196152832,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22570401792,\"adminState\":\"In Service\"},\"c1004.hal.cloudera.com\":{\"numBlocks\":30781,\"usedSpace\":2634844632278,\"lastContact\":0,\"capacity\":4945778647040,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1005.hal.cloudera.com\":{\"numBlocks\":43728,\"usedSpace\":3847359647744,\"lastContact\":1,\"capacity\":5672740315136,\"nonDfsUsedSpace\":39820255232,\"adminState\":\"In Service\"},\"c1112.hal.cloudera.com\":{\"numBlocks\":52374,\"usedSpace\":4476235318970,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0829.hal.cloudera.com\":{\"numBlocks\":45651,\"usedSpace\":4029717716068,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1009.hal.cloudera.com\":{\"numBlocks\":45718,\"usedSpace\":4002164694466,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1021.hal.cloudera.com\":{\"numBlocks\":46367,\"usedSpace\":3977306526017,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22848328743,\"adminState\":\"In Service\"},\"c0929.hal.cloudera.com\":{\"numBlocks\":47996,\"usedSpace\":4208970379264,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1024.hal.cloudera.com\":{\"numBlocks\":46138,\"usedSpace\":4035885617291,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22068686848,\"adminState\":\"In Service\"},\"c0814.hal.cloudera.com\":{\"numBlocks\":45184,\"usedSpace\":3963163342912,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":21469806592,\"adminState\":\"In Service\"},\"c1118.hal.cloudera.com\":{\"numBlocks\":52882,\"usedSpace\":4516858392171,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":2187436032,\"adminState\":\"In Service\"},\"c0921.hal.cloudera.com\":{\"numBlocks\":47378,\"usedSpace\":4158748622742,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0922.hal.cloudera.com\":{\"numBlocks\":48041,\"usedSpace\":4244605531944,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0931.hal.cloudera.com\":{\"numBlocks\":48115,\"usedSpace\":4206381940736,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1022.hal.cloudera.com\":{\"numBlocks\":46950,\"usedSpace\":4118345915265,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1017.hal.cloudera.com\":{\"numBlocks\":46169,\"usedSpace\":4028092525013,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1119.hal.cloudera.com\":{\"numBlocks\":53025,\"usedSpace\":4553547189077,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1010.hal.cloudera.com\":{\"numBlocks\":45360,\"usedSpace\":3922849998587,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0928.hal.cloudera.com\":{\"numBlocks\":47315,\"usedSpace\":4120677217319,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1115.hal.cloudera.com\":{\"numBlocks\":54050,\"usedSpace\":4684135854853,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1114.hal.cloudera.com\":{\"numBlocks\":52739,\"usedSpace\":4480289800192,\"lastContact\":0,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1027.hal.cloudera.com\":{\"numBlocks\":45224,\"usedSpace\":3895576203803,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0906.hal.cloudera.com\":{\"numBlocks\":47018,\"usedSpace\":4084728785792,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c1013.hal.cloudera.com\":{\"numBlocks\":44117,\"usedSpace\":3855729635684,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"},\"c0824.hal.cloudera.com\":{\"numBlocks\":49687,\"usedSpace\":4230217644443,\"lastContact\":1,\"capacity\":5688127021056,\"nonDfsUsedSpace\":22189756416,\"adminState\":\"In Service\"},\"c0830.hal.cloudera.com\":{\"numBlocks\":51357,\"usedSpace\":4423340997504,\"lastContact\":2,\"capacity\":5688127021056,\"nonDfsUsedSpace\":0,\"adminState\":\"In Service\"}}",
    "DeadNodes" : "{\"\":{\"lastContact\":1350591614,\"decommissioned\":false},\"c0818.hal.cloudera.com\":{\"lastContact\":1350591614,\"decommissioned\":false},\"c0930.hal.cloudera.com\":{\"lastContact\":1350591614,\"decommissioned\":false}}",
    "DecomNodes" : "{}",
    "NameDirStatuses" : "{\"failed\":{},\"active\":{\"/data/2/dfs/nn\":\"IMAGE_AND_EDITS\",\"/data/1/dfs/nn\":\"IMAGE_AND_EDITS\"}}"
  }, {
    "name" : "com.sun.management:type=HotSpotDiagnostic",
    "modelerType" : "sun.management.HotSpotDiagnostic",
    "DiagnosticOptions" : [ {
      "name" : "HeapDumpBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpOnOutOfMemoryError",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpPath",
      "origin" : "DEFAULT",
      "value" : "",
      "writeable" : true
    }, {
      "name" : "CMSAbortablePrecleanWaitMillis",
      "origin" : "DEFAULT",
      "value" : "100",
      "writeable" : true
    }, {
      "name" : "CMSWaitDuration",
      "origin" : "DEFAULT",
      "value" : "2000",
      "writeable" : true
    }, {
      "name" : "PrintGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDetails",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDateStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCTimeStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogram",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintConcurrentLocks",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    } ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Perm Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Perm Gen",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 81068032,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 46700416
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 81068032,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 46998016
    },
    "Usage" : {
      "committed" : 81068032,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 46998016
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS Scavenge",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 13,
      "duration" : 78,
      "endTime" : 179326290,
      "id" : 2913,
      "memoryUsageAfterGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 9371648,
          "init" : 32899072,
          "max" : 9371648,
          "used" : 9332024
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 849281024,
          "init" : 527171584,
          "max" : 2394947584,
          "used" : 654868240
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 81068032,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 46998016
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 9109504,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 8881856
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 1171521536,
          "init" : 197722112,
          "max" : 1175388160,
          "used" : 0
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 12779520,
          "init" : 32899072,
          "max" : 12779520,
          "used" : 10970496
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 849281024,
          "init" : 527171584,
          "max" : 2394947584,
          "used" : 654778128
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 81068032,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 46998016
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 9109504,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 8881856
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 1171521536,
          "init" : 197722112,
          "max" : 1171718144,
          "used" : 1171521536
        }
      } ],
      "startTime" : 179326212
    },
    "CollectionCount" : 2913,
    "CollectionTime" : 170003,
    "Name" : "PS Scavenge",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space" ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Old Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Old Gen",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 849281024,
      "init" : 527171584,
      "max" : 2394947584,
      "used" : 444802504
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 875823104,
      "init" : 527171584,
      "max" : 2394947584,
      "used" : 875303144
    },
    "Usage" : {
      "committed" : 849281024,
      "init" : 527171584,
      "max" : 2394947584,
      "used" : 654868240
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "JMImplementation:type=MBeanServerDelegate",
    "modelerType" : "javax.management.MBeanServerDelegate",
    "MBeanServerId" : "c1113.hal.cloudera.com_1350412166661",
    "SpecificationName" : "Java Management Extensions",
    "SpecificationVersion" : "1.4",
    "SpecificationVendor" : "Sun Microsystems",
    "ImplementationName" : "JMX",
    "ImplementationVersion" : "1.6.0_31-b04",
    "ImplementationVendor" : "Sun Microsystems"
  } ]
}
"""
