#!/bin/bash

# Copyright (c) 2011-2012 Cloudera, Inc. All rights reserved.

# Time marker for both stderr and stdout
date; date 1>&2

cloudera_config=`dirname $0`
cloudera_config=`cd "$cloudera_config/../common"; pwd`
. ${cloudera_config}/cloudera-config.sh

# attempt to find java
locate_java_home

# load the parcel environment
source_parcel_environment

if [ "4" = "$CDH_VERSION" ]; then
  export HADOOP_HOME=$CDH_MR1_HOME
  ADD_TO_CP=""
  ADD_TO_CP="$CDH_HADOOP_HOME/*:$ADD_TO_CP"
  ADD_TO_CP="$CDH_HADOOP_HOME/lib/*:$ADD_TO_CP"
  ADD_TO_CP="$CDH_HDFS_HOME/*:$ADD_TO_CP"
  ADD_TO_CP="$CDH_HDFS_HOME/lib/*:$ADD_TO_CP"
  export HADOOP_CLASSPATH="$ADD_TO_CP:$HADOOP_CLASSPATH"
  echo "using $HADOOP_CLASSPATH as HADOOP_CLASSPATH"

  # Disable IPv6. This is automatically done by bin/hadoop for CDH3.
  export HADOOP_OPTS="-Djava.net.preferIPv4Stack=true $HADOOP_OPTS"
elif [ "3" = "$CDH_VERSION" ] || [ "-3" = "$CDH_VERSION" ]; then
  export HADOOP_HOME=$CDH_HADOOP_HOME
else
  echo "ERROR: Unsupported version $CDH_VERSION"
  exit 1
fi

echo "using $JAVA_HOME as JAVA_HOME"
echo "using $CDH_VERSION as CDH_VERSION"
echo "using $HADOOP_HOME as HADOOP_HOME"
echo "using $CONF_DIR as HADOOP_CONF_DIR"

set_hadoop_classpath

# debug
set -x

# local replacement of substitution variables.
# i.e. master doesn't know final resting place of configuration files
#   which may require absolute path (e.g. dfs_allows)
perl -pi -e "s#{{CMF_CONF_DIR}}#$CONF_DIR#g" $CONF_DIR/*.xml

if [ -e $CONF_DIR/topology.py ]; then
  perl -pi -e "s#{{CMF_CONF_DIR}}#$CONF_DIR#g" $CONF_DIR/topology.py
  # Make sure topology.py is executable
  chmod +x $CONF_DIR/topology.py
fi

acquire_kerberos_tgt mapred.keytab

if [ $1 = "jobtracker" ]; then
  if [ z$ADD_CAPACITY_SCHEDULER = z"true" ]; then
    ADD_TO_CP=`find $HADOOP_HOME/contrib/capacity-scheduler -name 'hadoop-capacity-scheduler-*.jar' | tr -d "\n"`
    if [ -z $HADOOP_CLASSPATH ]; then
      export HADOOP_CLASSPATH="$ADD_TO_CP"
    else
      export HADOOP_CLASSPATH="$ADD_TO_CP:$HADOOP_CLASSPATH"
    fi
    env | grep HADOOP_CLASSPATH
  fi
elif [ $1 = "tasktracker" ]; then
  # Children need to be able to read the Hadoop config
  # files, so make those world-readable
  chmod 0644 $CONF_DIR/mapred-site.xml $CONF_DIR/hdfs-site.xml $CONF_DIR/core-site.xml $CONF_DIR/log4j.properties
elif [ $1 = "RefreshQueuesAndNodes" ]; then
  # If we are sending a refreshAll command to mradmin
  # it means we want to refresh queues and nodes
  RET=0
  $HADOOP_HOME/bin/hadoop --config $CONF_DIR mradmin -refreshQueues
  RET=$?
  if [ $RET -eq 0 ]; then
    echo "Refresh queues worked successfully"
    $HADOOP_HOME/bin/hadoop --config $CONF_DIR mradmin -refreshNodes
    RET=$?
    if [ $RET -eq 0 ]; then
      echo "Refresh nodes worked successfully"
    else
      echo "Refresh nodes failed"
    fi
  else
    echo "Refresh queues failed. Skipping refresh nodes."
  fi
  exit $RET
fi

exec $HADOOP_HOME/bin/hadoop --config $CONF_DIR "$@"
