-- Copyright (c) 2012 Cloudera, Inc. All rights reserved.
--
-- Version 1 of the CMON schema for Oracle.
-- The filename starts with version 7 to keep it in sync with
-- mysql and postresql databases.
--

-- The schema version, should be checked by the server during startup
CREATE TABLE CMON_SCHEMA_VERSION (
    VERSION number(4, 0) CONSTRAINT NOT_NULL_SCHEMA_VERSION NOT NULL
);

-- Update this value when the schema changes, also during migration
INSERT INTO CMON_SCHEMA_VERSION VALUES (7);

CREATE TABLE CMON_ACTIVITY (
    ID number(19,0) CONSTRAINT NOT_NULL_ACTIVITY_ID NOT NULL,
    SERVICE_NAME varchar2(255 char),
    NAME varchar2(255 char),
    BEGIN_TS number(19,0),
    END_TS number(19,0),
    ACTIVITY_TYPE number(10,0),
    PARENT_ID number(19,0),
    CONSTRAINT PK_CMON_ACTIVITY PRIMARY KEY (ID)
);

CREATE SEQUENCE CMON_ACTIVITY_ATTR_SEQUENCE
  START WITH 1
  NOMAXVALUE;

CREATE TABLE CMON_ACTIVITY_ATTRIBUTE (
    ID number(19,0) CONSTRAINT NOT_NULL_ACTIVITY_ATTR_ID NOT NULL,
    ACTIVITY_ID number(19,0),
    METRIC_ID number(10,0),
    STRING_ATTR varchar2(255 char),
    CONSTRAINT PK_CMON_ACTIVITY_ATTRIBUTE PRIMARY KEY (ID)
);

CREATE SEQUENCE CMON_ACTIVITY_DP_SEQUENCE
  START WITH 1
  NOMAXVALUE;

CREATE TABLE CMON_ACTIVITY_DP (
    ID number(19,0) CONSTRAINT NOT_NULL_ACTIVITY_DP_ID NOT NULL,
    SERIES_ID number(19,0),
    METRIC_ID number(10,0),
    TS number(19,0),
    VALUE double precision,
    CONSTRAINT PK_CMON_ACTIVITY_DP PRIMARY KEY (ID)
);

CREATE SEQUENCE CMON_ACTIVITY_LMV_SEQUENCE
  START WITH 1
  NOMAXVALUE;

CREATE TABLE CMON_ACTIVITY_LAST_METRIC_VAL (
    ID number(19,0) CONSTRAINT NOT_NULL_ACTIVITY_LMV_ID NOT NULL,
    ACTIVITY_ID number(19,0),
    METRIC_ID number(10,0),
    TS number(19,0),
    VALUE double precision,
    CONSTRAINT PK_CMON_ACTIVITY_LMV PRIMARY KEY (ID)
);

CREATE TABLE CMON_ATTEMPT (
    ID number(19,0) CONSTRAINT NOT_NULL_ATTEMPT_ID NOT NULL,
    NAME varchar2(255 char),
    BEGIN_TS NUMBER(19,0),
    END_TS NUMBER(19,0),
    HOST varchar2(255 CHAR),
    ATTEMPT_TYPE number(10,0) CONSTRAINT NOT_NULL_ATTEMPT_TYPE NOT NULL,
    ACTIVITY_ID number(19,0),
    CONSTRAINT CMON_ATTEMPT PRIMARY KEY (ID)
);

CREATE SEQUENCE CMON_ATTEMPT_LMV_SEQUENCE
  START WITH 1
  NOMAXVALUE;

CREATE TABLE CMON_ATTEMPT_LAST_METRIC_VAL (
    ID number(19,0) CONSTRAINT NOT_NULL_ATTEMPT_LMV_ID NOT NULL,
    ATTEMPT_ID number(19,0),
    METRIC_ID number(10,0),
    TS number(19,0),
    VALUE double precision,
    CONSTRAINT PK_CMON_ATTEMPT_LMV PRIMARY KEY (ID)
);

CREATE SEQUENCE CMON_LL_DP_SEQUENCE
  START WITH 1
  CACHE 10000
  NOMAXVALUE;

-- Oracle has 30 character limit on table and column names.
-- This needs to be less than 19 chars so that partitioning tables
-- fit within 30 chars. Partitioning adds _YYYY_MM_DD to the name
-- of this table.
-- Abbreviation LL_DP stand for Long Lived Data Points
CREATE TABLE CMON_LL_DP (
    ID number(19,0) CONSTRAINT NOT_NULL_LL_DP_ID NOT NULL,
    SERIES_ID number(19,0),
    METRIC_ID number(10,0),
    TS number(19,0),
    VALUE double precision,
    CONSTRAINT PK_CMON_LL_DP PRIMARY KEY (ID)
);

CREATE SEQUENCE CMON_LL_DP_HR_SEQUENCE
  START WITH 1
  CACHE 1000
  NOMAXVALUE;

-- This needs to be less than 19 chars so that partitioning tables
-- fit within 30 chars. Partitioning adds _YYYY_MM_DD to the name
-- of this table.
-- Abbreviation LL_DP stand for Long Lived Data Points
CREATE TABLE CMON_LL_DP_HR (
    ID number(19,0) CONSTRAINT NOT_NULL_LL_DP_HR_ID NOT NULL,
    SERIES_ID number(19,0),
    METRIC_ID number(10,0),
    START_TS number(19,0),
    TS number(19,0),
    END_TS number(19,0),
    AVERAGE double precision,
    MINIMUM double precision,
    MAXIMUM double precision,
    CONSTRAINT PK_CMON_LL_DP_HR PRIMARY KEY (ID)
);

CREATE TABLE CMON_LL_TIME_SERIES_ATTRIBUTE (
    ID number(10,0) CONSTRAINT NOT_NULL_LL_TSA_ID NOT NULL,
    ATTR_KEY varchar2(255 char),
    VALUE varchar2(255 char),
    SERIES_ID number(19,0),
    CONSTRAINT PK_CMON_LL_TSA PRIMARY KEY (ID)
);

CREATE TABLE CMON_LL_TIME_SERIES_ID (
    ID number(19,0) CONSTRAINT NOT_NULL_LL_TS_ID NOT NULL,
    CATEGORY number(10,0),
    NAME varchar2(255 char),
    CONSTRAINT PK_CMON_LL_TIME_SERIES_ID PRIMARY KEY (ID)
);

CREATE TABLE CMON_METRIC_INFO (
    METRIC_ID number(10,0) CONSTRAINT NOT_NULL_METRIC_INFO_ID NOT NULL,
    NAME varchar2(255 char),
    CONSTRAINT PK_CMON_METRIC_INFO PRIMARY KEY (METRIC_ID)
);

CREATE SEQUENCE PARTITION_INFO_SEQUENCE
  START WITH 1
  NOMAXVALUE;

create table CMON_PARTITION_INFO (
    ID number(19,0) CONSTRAINT NOT_NULL_PARTITION_INFO_ID NOT NULL,
    NAME varchar2(255 char),
    BASE_TABLE varchar2(255 char),
    END_TS number(19,0),
    CONSTRAINT PK_CMON_PARTITION_INFO PRIMARY KEY (ID)
);

CREATE INDEX IDX_ACTIVITY_BY_NAME ON CMON_ACTIVITY (NAME);

CREATE INDEX IDX_ACTIVITY_PARENT_ACTIVITY ON CMON_ACTIVITY (PARENT_ID);

CREATE INDEX IDX_ATTEMPT_SERIES_BY_NAME ON CMON_ACTIVITY (SERVICE_NAME);

ALTER TABLE CMON_ACTIVITY
    ADD CONSTRAINT FK_ACTIVITY_PARENT_ACTIVITY
    FOREIGN KEY (PARENT_ID)
    REFERENCES CMON_ACTIVITY
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_BY_ACTIVITY_ID ON CMON_ACTIVITY_ATTRIBUTE (ACTIVITY_ID);

ALTER TABLE CMON_ACTIVITY_ATTRIBUTE
    ADD CONSTRAINT FK_ACTIVITY_ATTR_ACTIVITY
    FOREIGN KEY (ACTIVITY_ID)
    REFERENCES CMON_ACTIVITY
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_ACTIVITY_DATA_LOOKUP ON CMON_ACTIVITY_DP (SERIES_ID, METRIC_ID, TS);

ALTER TABLE CMON_ACTIVITY_DP
    ADD CONSTRAINT FK_DP_ACTIVITY_ID
    FOREIGN KEY (SERIES_ID)
    REFERENCES CMON_ACTIVITY
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_ACTIVITY_BY_ACTIVITY_ID ON CMON_ACTIVITY_LAST_METRIC_VAL (ACTIVITY_ID);

ALTER TABLE CMON_ACTIVITY_LAST_METRIC_VAL
    ADD CONSTRAINT FK_ACTIVITY_LMV_ACTIVITY
    FOREIGN KEY (ACTIVITY_ID)
    REFERENCES CMON_ACTIVITY
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_ATTEMPT_ACTIVITY ON CMON_ATTEMPT (ACTIVITY_ID);

CREATE INDEX IDX_ATTEMPT_BY_NAME ON CMON_ATTEMPT (NAME);

ALTER TABLE CMON_ATTEMPT
    ADD CONSTRAINT FK_ATTEMPT_ACTIVITY
    FOREIGN KEY (ACTIVITY_ID)
    REFERENCES CMON_ACTIVITY
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_BY_ATTEMPT_ID ON CMON_ATTEMPT_LAST_METRIC_VAL (ATTEMPT_ID);

ALTER TABLE CMON_ATTEMPT_LAST_METRIC_VAL
    ADD CONSTRAINT FK_ATTEMPT_LMV_ATTEMPT
    FOREIGN KEY (ATTEMPT_ID)
    REFERENCES CMON_ATTEMPT
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_SERIES_METRIC_TS ON CMON_LL_DP (SERIES_ID, METRIC_ID, TS);
CREATE INDEX IDX_SUMMARY_CALC ON CMON_LL_DP (TS);
--
-- This foreign key only exists on the initial partitions. Other partitions
-- don't copy it over (see CreatePartitionTable.java).
-- OPSAPS-10606 has been opened to address this.
--
ALTER TABLE CMON_LL_DP
    ADD CONSTRAINT FK_LL_SERIES_ID
    FOREIGN KEY (SERIES_ID)
    REFERENCES CMON_LL_TIME_SERIES_ID
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_SERIES_METRIC_TS_HR ON CMON_LL_DP_HR (SERIES_ID, METRIC_ID, TS);
CREATE INDEX IDX_SUMMARY_CALC_HR ON CMON_LL_DP_HR (TS);

-- See the CMON_LL_DP comment regarding the foreign key
ALTER TABLE CMON_LL_DP_HR
    ADD CONSTRAINT FK_LL_HR_SERIES_ID
    FOREIGN KEY (SERIES_ID)
    REFERENCES CMON_LL_TIME_SERIES_ID
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_LLATTR_ID ON CMON_LL_TIME_SERIES_ATTRIBUTE (SERIES_ID);

ALTER TABLE CMON_LL_TIME_SERIES_ATTRIBUTE
    ADD CONSTRAINT FK_LLATTR_SERIES_ID
    FOREIGN KEY (SERIES_ID)
    REFERENCES CMON_LL_TIME_SERIES_ID
    DEFERRABLE INITIALLY IMMEDIATE;

CREATE INDEX IDX_SERIES_BY_NAME ON CMON_LL_TIME_SERIES_ID (NAME);

CREATE UNIQUE INDEX IDX_PARTITION_NAME ON CMON_PARTITION_INFO (NAME);
